# Ripple Source Guidelines

Each folder contains a single module following the newest style:

- One class per header
- As much implementation hidden as possible
- All major interfaces are abstract
- Every class is documented
- Each module focuses on solving one problem
